public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: "Philippe Mathieu-Daudé" <philmd@redhat.com>
To: devel@edk2.groups.io
Cc: Laszlo Ersek <lersek@redhat.com>, Eric Dong <eric.dong@intel.com>
Subject: [PATCH v3 42/78] NetworkPkg/Library: Fix various typos
Date: Fri,  7 Feb 2020 02:07:55 +0100	[thread overview]
Message-ID: <20200207010831.9046-43-philmd@redhat.com> (raw)
In-Reply-To: <20200207010831.9046-1-philmd@redhat.com>

From: Antoine Coeur <coeur@gmx.fr>

Fix various typos in comments and documentation.

Cc: Jiaxin Wu <jiaxin.wu@intel.com>
Cc: Siyuan Fu <siyuan.fu@intel.com>
Cc: Maciej Rabeda <maciej.rabeda@intel.com>
Signed-off-by: Antoine Coeur <coeur@gmx.fr>
Reviewed-by: Philippe Mathieu-Daude <philmd@redhat.com>
Reviewed-by: Maciej Rabeda <maciej.rabeda@intel.com>
Signed-off-by: Philippe Mathieu-Daude <philmd@redhat.com>
---
 NetworkPkg/Include/Library/HttpLib.h         |  2 +-
 NetworkPkg/Include/Library/IpIoLib.h         |  4 ++--
 NetworkPkg/Include/Library/NetLib.h          |  2 +-
 NetworkPkg/Include/Library/TcpIoLib.h        |  6 +++---
 NetworkPkg/Include/Library/UdpIoLib.h        |  6 +++---
 NetworkPkg/Library/DxeHttpLib/DxeHttpLib.c   |  4 ++--
 NetworkPkg/Library/DxeIpIoLib/DxeIpIoLib.c   | 16 ++++++++--------
 NetworkPkg/Library/DxeNetLib/DxeNetLib.c     | 16 ++++++++--------
 NetworkPkg/Library/DxeNetLib/NetBuffer.c     |  4 ++--
 NetworkPkg/Library/DxeTcpIoLib/DxeTcpIoLib.c | 10 +++++-----
 NetworkPkg/Library/DxeUdpIoLib/DxeUdpIoLib.c | 10 +++++-----
 11 files changed, 40 insertions(+), 40 deletions(-)

diff --git a/NetworkPkg/Include/Library/HttpLib.h b/NetworkPkg/Include/Library/HttpLib.h
index 93100eb350e5..a906126b3d6e 100644
--- a/NetworkPkg/Include/Library/HttpLib.h
+++ b/NetworkPkg/Include/Library/HttpLib.h
@@ -425,7 +425,7 @@ HttpFreeHeaderFields (
                                   the HTTP request message.
   @param[in]   Url                The URL of a remote host.
   @param[out]  RequestMsg         Pointer to the created HTTP request message.
-                                  NULL if any error occured.
+                                  NULL if any error occurred.
   @param[out]  RequestMsgSize     Size of the RequestMsg (in bytes).
 
   @retval EFI_SUCCESS             If HTTP request string was created successfully.
diff --git a/NetworkPkg/Include/Library/IpIoLib.h b/NetworkPkg/Include/Library/IpIoLib.h
index 2d6e090f754e..d95413e87eb1 100644
--- a/NetworkPkg/Include/Library/IpIoLib.h
+++ b/NetworkPkg/Include/Library/IpIoLib.h
@@ -403,7 +403,7 @@ IpIoOpen (
 
   This function is called after IpIoOpen(). The data to be sent is wrapped in
   Pkt. The IP instance wrapped in IpIo is used for sending by default but can be
-  overriden by Sender. Other sending configs, like source address and gateway
+  overridden by Sender. Other sending configs, like source address and gateway
   address etc., are specified in OverrideData.
 
   @param[in, out]  IpIo                  Pointer to an IP_IO instance used for sending IP
@@ -508,7 +508,7 @@ IpIoConfigIp (
 
   This function pairs with IpIoAddIp(). The IpInfo is previously created by
   IpIoAddIp(). The IP_IO_IP_INFO::RefCnt is decremented and the IP instance
-  will be dstroyed if the RefCnt is zero.
+  will be destroyed if the RefCnt is zero.
 
   @param[in]  IpIo                  The pointer to the IP_IO instance.
   @param[in]  IpInfo                The pointer to the IpInfo to be removed.
diff --git a/NetworkPkg/Include/Library/NetLib.h b/NetworkPkg/Include/Library/NetLib.h
index 786382a1fcff..858d0b6ba07c 100644
--- a/NetworkPkg/Include/Library/NetLib.h
+++ b/NetworkPkg/Include/Library/NetLib.h
@@ -748,7 +748,7 @@ EFI_STATUS
   If it has been removed, then restart the traversal from the head.
   If it hasn't been removed, then continue with the next node directly.
   This function will end the iterate and return the CallBack's last return value if error happens,
-  or retrun EFI_SUCCESS if 2 complete passes are made with no changes in the number of children in the list.
+  or return EFI_SUCCESS if 2 complete passes are made with no changes in the number of children in the list.
 
   @param[in]    List             The head of the list.
   @param[in]    CallBack         Pointer to the callback function to destroy one node in the list.
diff --git a/NetworkPkg/Include/Library/TcpIoLib.h b/NetworkPkg/Include/Library/TcpIoLib.h
index 63872f615c0a..13c163ce9920 100644
--- a/NetworkPkg/Include/Library/TcpIoLib.h
+++ b/NetworkPkg/Include/Library/TcpIoLib.h
@@ -200,7 +200,7 @@ TcpIoReset (
   @param[in]   TcpIo           The TcpIo wrapping the TCP socket.
   @param[in]   Packet          The packet to transmit.
 
-  @retval EFI_SUCCESS            The packet is trasmitted.
+  @retval EFI_SUCCESS            The packet is transmitted.
   @retval EFI_INVALID_PARAMETER  One or more parameters are invalid.
   @retval EFI_UNSUPPORTED        One or more of the control options are not
                                  supported in the implementation.
@@ -221,14 +221,14 @@ TcpIoTransmit (
 
   @param[in, out]  TcpIo       The TcpIo which wraps the socket to be destroyed.
   @param[in]       Packet      The buffer to hold the data copy from the socket rx buffer.
-  @param[in]       AsyncMode   Is this receive asyncronous or not.
+  @param[in]       AsyncMode   Is this receive asynchronous or not.
   @param[in]       Timeout     The time to wait for receiving the amount of data the Packet
                                can hold. Set to NULL for infinite wait.
 
   @retval EFI_SUCCESS            The required amount of data is received from the socket.
   @retval EFI_INVALID_PARAMETER  One or more parameters are invalid.
   @retval EFI_DEVICE_ERROR       An unexpected network or system error occurred.
-  @retval EFI_OUT_OF_RESOURCES   Failed to allocate momery.
+  @retval EFI_OUT_OF_RESOURCES   Failed to allocate memory.
   @retval EFI_TIMEOUT            Failed to receive the required amount of data in the
                                  specified time period.
   @retval Others                 Other errors as indicated.
diff --git a/NetworkPkg/Include/Library/UdpIoLib.h b/NetworkPkg/Include/Library/UdpIoLib.h
index c3cddfafb151..cd4ebeb87a43 100644
--- a/NetworkPkg/Include/Library/UdpIoLib.h
+++ b/NetworkPkg/Include/Library/UdpIoLib.h
@@ -43,7 +43,7 @@ typedef struct {
 
   This prototype is used by both receive and sending when calling
   UdpIoRecvDatagram() or UdpIoSendDatagram(). When receiving, Netbuf is allocated by the
-  UDP access point and released by the user. When sending, the user allocates the the NetBuf,
+  UDP access point and released by the user. When sending, the user allocates the NetBuf,
   which is then provided to the callback as a reference.
 
   @param[in] Packet       The packet received or sent.
@@ -197,7 +197,7 @@ BOOLEAN
 
   @param[in]  UdpIo                 The UDP_IO to cancel packet.
   @param[in]  IoStatus              The IoStatus to return to the packet owners.
-  @param[in]  ToCancel              The select funtion to test whether to cancel this
+  @param[in]  ToCancel              The select function to test whether to cancel this
                                     packet or not.
   @param[in]  Context               The opaque parameter to the ToCancel.
 
@@ -228,7 +228,7 @@ UdpIoCancelDgrams (
   @param[in]  ImageHandle           The image handle for the driver.
   @param[in]  Configure             The function to configure the created UDP child.
   @param[in]  UdpVersion            The UDP protocol version, UDP4 or UDP6.
-  @param[in]  Context               The opaque parameter for the Configure funtion.
+  @param[in]  Context               The opaque parameter for the Configure function.
 
   @return The newly-created UDP_IO, or NULL if failed.
 
diff --git a/NetworkPkg/Library/DxeHttpLib/DxeHttpLib.c b/NetworkPkg/Library/DxeHttpLib/DxeHttpLib.c
index 8b74554cd961..180d9321025a 100644
--- a/NetworkPkg/Library/DxeHttpLib/DxeHttpLib.c
+++ b/NetworkPkg/Library/DxeHttpLib/DxeHttpLib.c
@@ -1677,7 +1677,7 @@ HttpGetFieldNameAndValue (
 /**
   Free existing HeaderFields.
 
-  @param[in]  HeaderFields       Pointer to array of key/value header pairs waitting for free.
+  @param[in]  HeaderFields       Pointer to array of key/value header pairs waiting for free.
   @param[in]  FieldCount         The number of header pairs in HeaderFields.
 
 **/
@@ -1717,7 +1717,7 @@ HttpFreeHeaderFields (
                                   the HTTP request message.
   @param[in]   Url                The URL of a remote host.
   @param[out]  RequestMsg         Pointer to the created HTTP request message.
-                                  NULL if any error occured.
+                                  NULL if any error occurred.
   @param[out]  RequestMsgSize     Size of the RequestMsg (in bytes).
 
   @retval EFI_SUCCESS             If HTTP request string was created successfully.
diff --git a/NetworkPkg/Library/DxeNetLib/DxeNetLib.c b/NetworkPkg/Library/DxeNetLib/DxeNetLib.c
index 4f8a1226dae7..2a555a7b90fa 100644
--- a/NetworkPkg/Library/DxeNetLib/DxeNetLib.c
+++ b/NetworkPkg/Library/DxeNetLib/DxeNetLib.c
@@ -36,7 +36,7 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 #define DEFAULT_ZERO_START     ((UINTN) ~0)
 
 //
-// All the supported IP4 maskes in host byte order.
+// All the supported IP4 masks in host byte order.
 //
 GLOBAL_REMOVE_IF_UNREFERENCED IP4_ADDR  gIp4AllMasks[IP4_MASK_NUM] = {
   0x00000000,
@@ -130,7 +130,7 @@ GLOBAL_REMOVE_IF_UNREFERENCED VLAN_DEVICE_PATH mNetVlanDevicePathTemplate = {
   to send the syslog packets. The caller isn't required to close
   the SNP after use because the SNP is opened by HandleProtocol.
 
-  @return The point to SNP if one is properly openned. Otherwise NULL
+  @return The point to SNP if one is properly opened. Otherwise NULL
 
 **/
 EFI_SIMPLE_NETWORK_PROTOCOL *
@@ -304,7 +304,7 @@ SyslogSendPacket (
   @param[in]  File      The file that contains the current log
   @param[in]  Line      The line of code in the File that contains the current log
   @param[in]  Message   The log message
-  @param[in]  BufLen    The lenght of the Buf
+  @param[in]  BufLen    The length of the Buf
   @param[out] Buf       The buffer to put the packet data
 
   @return The length of the syslog packet built, 0 represents no packet is built.
@@ -480,7 +480,7 @@ NetDebugASPrint (
   Because it isn't open the SNP BY_DRIVER, apply caution when using it.
 
   @param Level    The severity level of the message.
-  @param Module   The Moudle that generates the log.
+  @param Module   The Module that generates the log.
   @param File     The file that contains the log.
   @param Line     The exact line that contains the log.
   @param Message  The user message to log.
@@ -518,7 +518,7 @@ NetDebugOutput (
   }
 
   //
-  // Allocate a maxium of 1024 bytes, the caller should ensure
+  // Allocate a maximum of 1024 bytes, the caller should ensure
   // that the message plus the ethernet/ip/udp header is shorter
   // than this
   //
@@ -1129,7 +1129,7 @@ NetListInsertBefore (
   If it has been removed, then restart the traversal from the head.
   If it hasn't been removed, then continue with the next node directly.
   This function will end the iterate and return the CallBack's last return value if error happens,
-  or retrun EFI_SUCCESS if 2 complete passes are made with no changes in the number of children in the list.
+  or return EFI_SUCCESS if 2 complete passes are made with no changes in the number of children in the list.
 
   @param[in]    List             The head of the list.
   @param[in]    CallBack         Pointer to the callback function to destroy one node in the list.
@@ -1353,7 +1353,7 @@ NetMapGetCount (
   Return one allocated item.
 
   If the Recycled doubly linked list of the netmap is empty, it will try to allocate
-  a batch of items if there are enough resources and add corresponding nodes to the begining
+  a batch of items if there are enough resources and add corresponding nodes to the beginning
   of the Recycled doubly linked list of the netmap. Otherwise, it will directly remove
   the fist node entry of the Recycled doubly linked list and return the corresponding item.
 
@@ -3299,7 +3299,7 @@ NetLibGetSystemGuid (
     String = (CHAR8 *) (Smbios.Raw + Smbios.Hdr->Length);
 
     //
-    // Step 2: Skip over unformated string section.
+    // Step 2: Skip over unformatted string section.
     //
     do {
       //
diff --git a/NetworkPkg/Library/DxeNetLib/NetBuffer.c b/NetworkPkg/Library/DxeNetLib/NetBuffer.c
index 2408e9a10456..a232802c9a21 100644
--- a/NetworkPkg/Library/DxeNetLib/NetBuffer.c
+++ b/NetworkPkg/Library/DxeNetLib/NetBuffer.c
@@ -602,7 +602,7 @@ NetbufGetFragment (
 
   if (HeadSpace != 0) {
     //
-    // Allocate an extra block to accomdate the head space.
+    // Allocate an extra block to accommodate the head space.
     //
     BlockOpNum++;
 
@@ -791,7 +791,7 @@ NetbufFromExt (
 
         if (Len == 0) {
           //
-          // Increament the index number to point to the next
+          // Increment the index number to point to the next
           // non-empty fragment.
           //
           Index++;
diff --git a/NetworkPkg/Library/DxeTcpIoLib/DxeTcpIoLib.c b/NetworkPkg/Library/DxeTcpIoLib/DxeTcpIoLib.c
index 341295d0b7af..6f87a0eada98 100644
--- a/NetworkPkg/Library/DxeTcpIoLib/DxeTcpIoLib.c
+++ b/NetworkPkg/Library/DxeTcpIoLib/DxeTcpIoLib.c
@@ -304,7 +304,7 @@ TcpIoCreateSocket (
   }
 
   //
-  // Create events for variuos asynchronous operations.
+  // Create events for various asynchronous operations.
   //
   Status = gBS->CreateEvent (
                   EVT_NOTIFY_SIGNAL,
@@ -745,7 +745,7 @@ TcpIoReset (
   @param[in]   TcpIo           The TcpIo wrapping the TCP socket.
   @param[in]   Packet          The packet to transmit.
 
-  @retval EFI_SUCCESS            The packet is trasmitted.
+  @retval EFI_SUCCESS            The packet is transmitted.
   @retval EFI_INVALID_PARAMETER  One or more parameters are invalid.
   @retval EFI_UNSUPPORTED        One or more of the control options are not
                                  supported in the implementation.
@@ -807,7 +807,7 @@ TcpIoTransmit (
   Status = EFI_DEVICE_ERROR;
 
   //
-  // Trasnmit the packet.
+  // Transmit the packet.
   //
   if (TcpIo->TcpVersion == TCP_VERSION_4) {
     TcpIo->TxToken.Tcp4Token.Packet.TxData = (EFI_TCP4_TRANSMIT_DATA *) Data;
@@ -862,14 +862,14 @@ TcpIoTransmit (
 
   @param[in, out]  TcpIo       The TcpIo which wraps the socket to be destroyed.
   @param[in]       Packet      The buffer to hold the data copy from the socket rx buffer.
-  @param[in]       AsyncMode   Is this receive asyncronous or not.
+  @param[in]       AsyncMode   Is this receive asynchronous or not.
   @param[in]       Timeout     The time to wait for receiving the amount of data the Packet
                                can hold. Set to NULL for infinite wait.
 
   @retval EFI_SUCCESS            The required amount of data is received from the socket.
   @retval EFI_INVALID_PARAMETER  One or more parameters are invalid.
   @retval EFI_DEVICE_ERROR       An unexpected network or system error occurred.
-  @retval EFI_OUT_OF_RESOURCES   Failed to allocate momery.
+  @retval EFI_OUT_OF_RESOURCES   Failed to allocate memory.
   @retval EFI_TIMEOUT            Failed to receive the required amount of data in the
                                  specified time period.
   @retval Others                 Other errors as indicated.
diff --git a/NetworkPkg/Library/DxeUdpIoLib/DxeUdpIoLib.c b/NetworkPkg/Library/DxeUdpIoLib/DxeUdpIoLib.c
index 155cb3104972..0034a5694f92 100644
--- a/NetworkPkg/Library/DxeUdpIoLib/DxeUdpIoLib.c
+++ b/NetworkPkg/Library/DxeUdpIoLib/DxeUdpIoLib.c
@@ -147,7 +147,7 @@ UdpIoRecycleDgram (
 /**
   The event handle for UDP receive request.
 
-  It will build a NET_BUF from the recieved UDP data, then deliver it
+  It will build a NET_BUF from the received UDP data, then deliver it
   to the receiver.
 
   @param[in]  Context               The UDP RX token.
@@ -335,7 +335,7 @@ UdpIoOnDgramRcvd (
   @param[in]  UdpIo                 The UdpIo to receive packets from.
   @param[in]  CallBack              The function to call when receive finished.
   @param[in]  Context               The opaque parameter to the CallBack.
-  @param[in]  HeadLen               The head length to reserver for the packet.
+  @param[in]  HeadLen               The head length to reserve for the packet.
 
   @return The Wrapped request or NULL if failed to allocate resources or some errors happened.
 
@@ -410,7 +410,7 @@ UdpIoCreateRxToken (
   @param[in]  UdpIo                 The UdpIo to send packet to.
   @param[in]  Packet                The user's packet.
   @param[in]  EndPoint              The local and remote access point.
-  @param[in]  Gateway               The overrided next hop.
+  @param[in]  Gateway               The overridden next hop.
   @param[in]  CallBack              The function to call when transmission completed.
   @param[in]  Context               The opaque parameter to the call back.
 
@@ -590,7 +590,7 @@ UdpIoCreateTxToken (
   @param[in]  ImageHandle           The image handle for the driver.
   @param[in]  Configure             The function to configure the created UDP child.
   @param[in]  UdpVersion            The UDP protocol version, UDP4 or UDP6.
-  @param[in]  Context               The opaque parameter for the Configure funtion.
+  @param[in]  Context               The opaque parameter for the Configure function.
 
   @return Newly-created UDP_IO or NULL if failed.
 
@@ -755,7 +755,7 @@ UdpIoCreateIo (
 
   @param[in]  UdpIo                 The UDP_IO to cancel packet.
   @param[in]  IoStatus              The IoStatus to return to the packet owners.
-  @param[in]  ToCancel              The select funtion to test whether to cancel this
+  @param[in]  ToCancel              The select function to test whether to cancel this
                                     packet or not.
   @param[in]  Context               The opaque parameter to the ToCancel.
 
diff --git a/NetworkPkg/Library/DxeIpIoLib/DxeIpIoLib.c b/NetworkPkg/Library/DxeIpIoLib/DxeIpIoLib.c
index d45f0070b3fc..0a816da00140 100644
--- a/NetworkPkg/Library/DxeIpIoLib/DxeIpIoLib.c
+++ b/NetworkPkg/Library/DxeIpIoLib/DxeIpIoLib.c
@@ -123,7 +123,7 @@ IpIoTransmitHandler (
 
   @retval       EFI_SUCCESS        The IP child is created and the IP protocol
                                    interface is retrieved.
-  @retval       EFI_UNSUPPORTED    Upsupported IpVersion.
+  @retval       EFI_UNSUPPORTED    Unsupported IpVersion.
   @retval       Others             The required operation failed.
 
 **/
@@ -191,7 +191,7 @@ IpIoCreateIpChildOpenProtocol (
 
 
 /**
-  This function close the previously openned IP protocol and destroy the IP child.
+  This function close the previously opened IP protocol and destroy the IP child.
 
   @param[in]  ControllerHandle    The controller handle.
   @param[in]  ImageHandle         The image handle.
@@ -201,7 +201,7 @@ IpIoCreateIpChildOpenProtocol (
 
   @retval     EFI_SUCCESS         The IP protocol is closed and the relevant IP child
                                   is destroyed.
-  @retval     EFI_UNSUPPORTED     Upsupported IpVersion.
+  @retval     EFI_UNSUPPORTED     Unsupported IpVersion.
   @retval     Others              The required operation failed.
 
 **/
@@ -228,7 +228,7 @@ IpIoCloseProtocolDestroyIpChild (
   }
 
   //
   // Close the previously openned IP protocol.
   //
   Status = gBS->CloseProtocol (
                   ChildHandle,
@@ -626,7 +626,7 @@ IpIoExtFree (
   @param[in]       Context              Pointer to the context.
   @param[in]       NotifyData           Pointer to the notify data.
   @param[in]       Dest                 Pointer to the destination IP address.
-  @param[in]       Override             Pointer to the overriden IP_IO data.
+  @param[in]       Override             Pointer to the overridden IP_IO data.
 
   @return Pointer to the data structure created to wrap the packet. If any error occurs,
           then return NULL.
@@ -1497,7 +1497,7 @@ IpIoStop (
   IpIo->IsConfigured = FALSE;
 
   //
-  // Detroy the Ip List used by IpIo
+  // Destroy the Ip List used by IpIo
   //
 
   while (!IsListEmpty (&(IpIo->IpList))) {
@@ -1577,7 +1577,7 @@ IpIoDestroy (
 
   This function is called after IpIoOpen(). The data to be sent is wrapped in
   Pkt. The IP instance wrapped in IpIo is used for sending by default but can be
-  overriden by Sender. Other sending configs, like source address and gateway
+  overridden by Sender. Other sending configs, like source address and gateway
   address etc., are specified in OverrideData.
 
   @param[in, out]  IpIo                  Pointer to an IP_IO instance used for sending IP
@@ -1991,7 +1991,7 @@ IpIoConfigIp (
 
   This function pairs with IpIoAddIp(). The IpInfo is previously created by
   IpIoAddIp(). The IP_IO_IP_INFO::RefCnt is decremented and the IP instance
-  will be dstroyed if the RefCnt is zero.
+  will be destroyed if the RefCnt is zero.
 
   @param[in]  IpIo                  Pointer to the IP_IO instance.
   @param[in]  IpInfo                Pointer to the IpInfo to be removed.
@@ -228,7 +228,7 @@ IpIoCloseProtocolDestroyIpChild (
 
   //
-  // Close the previously openned IP protocol.
+  // Close the previously opened IP protocol.
   //
   Status = gBS->CloseProtocol (
-- 
2.21.1


  parent reply	other threads:[~2020-02-07  1:40 UTC|newest]

Thread overview: 84+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-02-07  1:07 [PATCH v3 00/78] Fix a bunch of typos (part 1) Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 01/78] CryptoPkg/OpensslLib: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 02/78] EmbeddedPkg/VirtualKeyboard: Fix a typo in EFI_INVALID_PARAMETER Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 03/78] EmbeddedPkg/VirtualKeyboard: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 04/78] EmulatorPkg/Sec: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 05/78] EmulatorPkg/Unix: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 06/78] EmulatorPkg/Win: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 07/78] FatPkg/EnhancedFatDxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 08/78] FatPkg/FatPei: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 09/78] MdeModulePkg/Application: Improve French translation Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 10/78] MdeModulePkg/Application: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 11/78] MdeModulePkg/Bus/Ata: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 12/78] MdeModulePkg/Bus/I2c: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 13/78] MdeModulePkg/Bus/Isa: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 14/78] MdeModulePkg/Bus/Scsi: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 15/78] MdeModulePkg/Bus/Sd: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 16/78] MdeModulePkg/Core/Pei: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 17/78] MdeModulePkg/Core/PiSmmCore: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 18/78] MdeModulePkg/UsbBusDxe: Fix a typo Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 19/78] MdeModulePkg/UsbMass: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 20/78] MdeModulePkg/UsbMouse: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 21/78] MdeModulePkg/UsbBus: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 22/78] MdeModulePkg/Usb: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 23/78] MdePkg/IndustryStandard: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 24/78] MdePkg/Library/Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 25/78] MdePkg/Library/Pci: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 26/78] MdePkg/Library/Smm: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 27/78] MdePkg/Ppi: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 28/78] MdePkg/Register: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 29/78] NetworkPkg: Fix a typo Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 30/78] NetworkPkg/ArpDxe: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 31/78] NetworkPkg/Dhcp4Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 32/78] NetworkPkg/Dhcp6Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 33/78] NetworkPkg/DnsDxe: Fix a typo Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 34/78] NetworkPkg/DnsDxe: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 35/78] NetworkPkg/DpcDxe: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 36/78] NetworkPkg/HttpBootDxe: Fix a typo in variable name Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 37/78] NetworkPkg/HttpBootDxe: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 38/78] NetworkPkg/HttpDxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 39/78] NetworkPkg/Ip4Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 40/78] NetworkPkg/Ip6Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 41/78] NetworkPkg/IScsiDxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` Philippe Mathieu-Daudé [this message]
2020-02-07  1:07 ` [PATCH v3 43/78] NetworkPkg/MnpDxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 44/78] NetworkPkg/Mtftp4Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 45/78] NetworkPkg/Mtftp6Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 46/78] NetworkPkg/SnpDxe: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 47/78] NetworkPkg/TcpDxe/Sock: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 48/78] NetworkPkg/TcpDxe/Tcp: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 49/78] NetworkPkg/Tls: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 50/78] NetworkPkg/Udp4Dxe: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 51/78] NetworkPkg/Udp6Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 52/78] NetworkPkg/UefiPxeBcDxe: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 53/78] NetworkPkg/VlanConfigDxe: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 54/78] OvmfPkg/Acpi: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 55/78] OvmfPkg/Csm: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 56/78] OvmfPkg/Csm/LegacyBios: Fix a typo Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 57/78] OvmfPkg/Qemu: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 58/78] OvmfPkg/Virtio: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 59/78] OvmfPkg/Xen: Fix a typo Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 60/78] OvmfPkg/Xen: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 61/78] PcAtChipsetPkg: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 62/78] SecurityPkg: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 63/78] SecurityPkg/Hash2DxeCrypto: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 64/78] SecurityPkg/Library/Tpm: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 65/78] SecurityPkg/Tcg: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 66/78] SecurityPkg/VariableAuthenticated: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 67/78] ShellPkg/Application: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 68/78] ShellPkg/DynamicCommand: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 69/78] SignedCapsulePkg: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 70/78] SignedCapsulePkg/Universal: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 71/78] SourceLevelDebugPkg/DebugAgent: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 72/78] SourceLevelDebugPkg/DebugCommunicationLib: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 73/78] SourceLevelDebugPkg: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 74/78] StandaloneMmPkg: Fix a typo Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 75/78] StandaloneMmPkg: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 76/78] UefiCpuPkg/CpuDxe: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 77/78] UefiCpuPkg/PiSmm: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 78/78] UefiCpuPkg/Smm: " Philippe Mathieu-Daudé
2020-02-07 10:51 ` [PATCH v3 00/78] Fix a bunch of typos (part 1) Laszlo Ersek
2020-02-10 22:54   ` [edk2-devel] " Laszlo Ersek
2020-02-11 12:12     ` Philippe Mathieu-Daudé
2020-02-12 12:02       ` Laszlo Ersek
2020-02-12 17:01     ` Cœur

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20200207010831.9046-43-philmd@redhat.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox